==> Sympathy-1.5.0.post2-py2.py3-none-any.whl: sympathy_app/Library/Test/Workflow/convert_columns/test_datatime_functions.py <==
# -*- coding:utf-8 -*-
# Copyright (c) 2017, System Engineering Software Society
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the System Engineering Software Society nor the
#       names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.
# IN NO EVENT SHALL SYSTEM ENGINEERING SOFTWARE SOCIETY BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
from sympathy.api import fx_wrapper


class TesTDatetimeFormats(fx_wrapper.FxWrapper):
    """
    Test if self.in_table is equivalent with self.extra_table. Test is
    performed to check the exportation of datetime to csv.
    """

    arg_types = ['(table, [table])', '[table]']

    def execute(self):
        extra_table, in_tables = self.arg
        self.res = []
        for column in extra_table.column_names():
            ref_col = extra_table.get_column_to_array(column).tolist()
            try:
                in_col = in_tables[0].get_column_to_array(column).tolist()
            except KeyError:
                raise KeyError(
                    'Incoming Table seem to lost a column along the way')

            self.res.append(
                all([in_value == ref_value for in_value, ref_value in zip(
                    in_col, ref_col)]))

        if not all(self.res):
            raise Exception(
                'Exportation of datetime object to csv was not performed '
                'correctly.')

==> Sympathy-1.5.2-py2.py3-none-any.whl: sympathy_app/Library/Test/Workflow/convert_columns/test_datatime_functions.py <==
# -*- coding:utf-8 -*-
# Copyright (c) 2017, System Engineering Software Society
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the System Engineering Software Society nor the
#       names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.
# IN NO EVENT SHALL SYSTEM ENGINEERING SOFTWARE SOCIETY BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
from sympathy.api import fx_wrapper


class TesTDatetimeFormats(fx_wrapper.FxWrapper):
    """
    Test if self.in_table is equivalent with self.extra_table. Test is
    performed to check the export of datetime to csv.
    """

    arg_types = ['(table, [table])', '[table]']

    def execute(self):
        extra_table, in_tables = self.arg
        self.res = []
        for column in extra_table.column_names():
            ref_col = extra_table.get_column_to_array(column).tolist()
            try:
                in_col = in_tables[0].get_column_to_array(column).tolist()
            except KeyError:
                raise KeyError(
                    'Incoming Table seem to lost a column along the way')

            self.res.append(
                all([in_value == ref_value for in_value, ref_value in zip(
                    in_col, ref_col)]))

        if not all(self.res):
            raise Exception(
                'Export of datetime object to csv was not performed '
                'correctly.')
